coherence.extern (package) — Cohen3 0.8.0 documentation

# coherence.extern (package)

The coherence.extern package contains some external dependencies included into this project. Those external dependencies are included because the source code may be slightly different from the original projects, don’t have an installer, are unmaintained…

Some of this external dependencies may be replaced or removed depending on the status of the Cohen3 project.

- coherence.extern.covers_by_amazon (module)
  - Covers by Amazon
- coherence.extern.db_row (module)
- coherence.extern.simple_plugin (module)
  - Simple Plugin
- coherence.extern.xdg (module)

## coherence.extern.galleryremote (package)

- coherence.extern.galleryremote.gallery (module)

## coherence.extern.youtubedl (package)

- coherence.extern.youtubedl.youtubedl (module)